/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

SHUTTLE.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// SHUTTLE.INC - Imperial Lambda-class shuttle model file
// Written by D M Beattie ( dmb197@ecs.soton.ac.uk )

// Definitions:
// object {Shuttle} - Shuttle in flight, wings open
// object {L_Shuttle} - Shuttle in landed configuration (no landing gear yet, though!)

#declare SH_HullTex1 = texture {
    pigment {
		granite
		colour_map {
			[0.0 colour rgb <0.95,0.98,1>]
			[0.2 colour rgb <0.95,0.98,1>]
			[0.4 colour rgb <0.92,0.93,0.97>]
			[0.8 colour rgb <0.89,0.92,0.95>]
			[1.0 colour rgb <0.95,0.98,1>]
		}
	}
	finish {diffuse 0.7 ambient 0}
}
#declare SH_HullTex2 = texture {
    pigment {
		granite
		colour_map {
			[0.0 colour rgb <0.85,0.88,0.9>]
			[0.2 colour rgb <0.85,0.88,0.9>]
			[0.4 colour rgb <0.82,0.83,0.87>]
			[0.8 colour rgb <0.79,0.82,0.85>]
			[1.0 colour rgb <0.85,0.88,0.9>]
		}
	}
	finish {diffuse 0.7 ambient 0}
}

#declare SH_ScreenTex = texture {
    pigment {colour rgb 0}
    finish {specular 0.9 roughness 0.01 reflection 0.2 ambient 0 diffuse 0.7}
}

#declare SH_GunTex1 = texture {
	pigment {colour rgb 0.6}
	finish {diffuse 0.7 ambient 0}
}


#declare SH_FormationLight = object {
	sphere {<0,0,0>, 1}
	hollow
	no_shadow
	texture {
		pigment {colour rgbt 1}
		halo {
			emitting
			spherical_mapping
			linear
			colour_map {
				[0 colour rgbt <1,1,0.8,1>]
				[0.5 colour rgbt <1,1,0.9,0.5>]
				[1 colour rgbt <1,1,1,-1>]
			}
			samples 10
		}
	}
	scale 0.33
}

#declare SH_TopWing = object {
	union {
		object { // Wing mounting
			intersection {
				object {
					union {
						object {cone {<0,-0.25,-0.2>, 1.5, <0,1.2,-0.2>, 0.7}}
						object {cone {<0,-0.25,0.7>, 0.8, <0,0.8,0.7>, 0.3}}
					}
					scale <100,1,1>
				}
				object {
					difference {
						object {
							union {
								object {cone {<0,0,0>, 0.8, <0,1.201,0>, 0.5}}
								object {cylinder {<0,-0.25,0>, <0,0.001,0>, 0.8}}
							}
							scale <1,1,100>
						}
						#declare SH_Foo1 = 0.3
						#declare SH_Foo2 = union {
							object {box {<-1.1, -0.25, -3>, <-SH_Foo1, 2, -0.6>}}
							object {box {<-1.1, -0.25, -0.5>, <-SH_Foo1, 2, -0.05>}}
							object {box {<-1.1, -0.25, 0.05>, <-SH_Foo1, 2, 0.5>}}
							object {box {<-1.1, -0.25, 0.6>, <-SH_Foo1, 2, 3>}}
							object {box {<-3,0.8,-4>, <-(SH_Foo1+0.0001),2,3>}}
							translate <0,0,-0.2>
						}
						object {SH_Foo2 scale <1,1,1>}
						object {SH_Foo2 scale <-1,1,1>}
					}
				}
			}
		}
		object {
			SH_FormationLight translate <0,8,1.5>
		}
		object {
			intersection { // Front end of top wing - including detail cut out of leading edge
				object {box {<-0.1,0,0>, <0.1,10,5>}}
				object {box {<-0.08, 0.08, 3>, <0.08, 1.32, 5.1>} inverse}
				object {
					difference {
						object {box {<-0.05,1.48, 0>, <0.05, 7.92, 5.01>}}
						object {cone {<0,1.4,0>, 4.8, <0,8,0>, 1.3} scale <100,1,1>}
					}
					inverse
				}
				object {
					union {
						object {cone {<0,0,0>, 4, <0,1.4,0>, 5} scale <100,1,1>}
						object {cone {<0,1.4,0>, 5, <0,8,0>, 1.5} scale <100,1,1>}
					}
				}
			}
		}
		object { // Rear end of top wing
			intersection {
				object {box {<-0.1,0,-5>, <0.1,10,0>}}
				object {cone {<0,0,0>, 2, <0,8,0>, 0.8} scale <100,1,1>}
			}
		}
	}
	texture { // Bump map and image map
		SH_HullTex1
		normal {
			bump_map {
				gif "sh_bmap1.gif" once
				bump_size 2
			}
			rotate <0,-90,0>
			scale 9	
			translate <0,-0.5,-2.5>
		}
	}
}

#declare SH_Gun1 = object {
	union {
		object {
			difference {
				object {sphere {<0,0,0>, 1} scale <1,1,1.5>}
				object {sphere {<0,0,0>, 1} scale <0.9,0.9,1.4>}
				object {plane {<0,0,1>, 0}}
				object {plane {<0,1,0>, 0}}
				object {cylinder {<0,0,-1>, <0,0,1.51>, 0.5}}
			}
		}
		object {cylinder {<0,0,0>, <0,0,0.1>, 1.1}}
		object {cylinder {<0,0,0>, <0,0,0.15>, 1.05}}
		object {
			intersection {
				object {box {<-0.5,-1,0.1>, <0.5,0,1.2>}}
				object {cone {<0,-0.4,0>, 0.7, <0,0,0>, 1} scale <100,1,1>}
			}
		}
		object {
			intersection {
				object {box {<-0.5,0,0.1>, <0.5,1,1>}}
				object {sphere {<0,0,0>, 1} scale <0.9,0.9,1.4>}
			}
		}
		object {cylinder {<0.15,0.4,1>, <0.15,0.4,1.5>, 0.05}}
		object {cylinder {<0.15,0.4,1>, <0.15,0.4,1.8>, 0.02}}
		object {cylinder {<0.15,0.4,1>, <0.15,0.4,1.5>, 0.05} scale <-1,1,1>}
		object {cylinder {<0.15,0.4,1>, <0.15,0.4,1.8>, 0.02} scale <-1,1,1>}
		
		#declare SH_GunPartB = object {
			union {
				object {cylinder {<0.2,0.1,1>, <0.2,0.1,1.6>, 0.1}}
				object {
					difference {
						object {cylinder {<0.2,0.1,1>, <0.2,0.1,2.1>, 0.06}}
						object {cylinder {<0.2,0.1,1>, <0.2,0.1,2.2>, 0.05}}
					}
				}
				object {
					difference {
						object {cylinder {<0.2,0.1,1.8>, <0.2,0.1,2.0>, 0.07}}
						object {cylinder {<0.2,0.1,1>, <0.2,0.1,2.2>, 0.05}}
					}
				}
			}
		}
		object {SH_GunPartB scale <1,1,1>}
		object {SH_GunPartB scale <-1,1,1>}
		
	}
	texture {SH_HullTex1}
	scale 0.4
}



#declare SH_Body = object {
	union {
		object { // Top section directly below wing mounting
			intersection {
				object {
					superellipsoid {<0.2,0.2>}
					scale <1,0.5,2.25>
					translate <0,0,0.25>
				}
				object {
					intersection {
						object {
							superellipsoid {<0.2,0.2>}
							scale <0.95,0.45,1>
							translate <0,0,-1.25>
						}
						object {
							box {<-1,-1,-3>, <1,1,-1>}
						}
					}
					inverse
				}
				object {plane {<0,1,0>, 0} rotate <35,0,0> translate <0,0,2.5>}
				object {cylinder {<0,0,0>, <0,0,3>, 1} scale <0.8,0.2,1> translate <0,0.25,0> inverse texture {pigment {colour rgb 0.1}}}
				object {box {<-0.8,-0.01,0>, <0.8,0.25,3>} inverse texture {pigment {colour rgb 0.1}}}
				object {plane {<0,-1,0>, 0}}
				object {box {<0,-1,0>, <10,2,10>} rotate <0,-45,0> scale <1,1,0.6> translate <0,0,-1.75>}
			}
		}
		object { // Middle section (vertically)
			union {
				#declare SH_Foo3 = object {
					union {
						object {box {<-1.4,-1.2,-1.5>, <1.4, 0, 3.5>}}
						object {
							difference {
								object {
									union {
										object {cylinder {<0,0,-1.5>, <0,0,3.5>, 1} scale <0.4,1.2,1> translate <-1.4,-1.2,0>}
										object {cylinder {<0,0,-1.5>, <0,0,3.5>, 1} scale <0.4,1.2,1> translate <1.4,-1.2,0>}
									}
								}
								object {plane {<0,1,0>, 0} translate <0,-1.2,0>}
							}
						}
					}
				}
				object {
					difference {
						object {SH_Foo3}
						object {SH_Foo3 scale <0.95,1,1> translate <0,-0.05,1.5+3.25>}
						object {SH_Foo3 scale <0.95,1,1> translate <0,-0.05,-4.5>}
						object {plane {<0,1,0>, 0} rotate <65,0,0> translate <0,0,-1.5>}
						object {box {<-0.95,-0.2,-2>, <0.95,0.2,-0.999>}}
					}
				}
				#declare SHMidSideDetail = object { // Detail along sides of middle section inc. cooling intakes
					union {
						object {
							difference {
								object {sphere {<0,0,0>, 1} scale <0.4,0.3,2>}
								object {plane {<0,0,-1>, 0}}
								object {sphere {<0,0,0>, 0.9} scale <0.4,0.3,0.4> texture {pigment {colour rgb 0}}}
							}
							translate <-1.8,-0.8,3.5>
						}
					}
				}
				object {
					difference {
						object {
							union {
								object {SHMidSideDetail scale <1,1,1>}
								object {SHMidSideDetail scale <-1,1,1>}
							}
						}
						object {SH_Foo3 scale <1,1,1.1>}
					}
				}
			}
		}
		object { // Lower section of body
			difference {
				object {
					union {
						object {box {<-2.6,-2.4,-1.2>, <2.6,-1.2,3.5>}}
						object {cylinder {<2.6,-1.8,-1.2>, <2.6,-1.8,3.5>, 0.6}}
						object {cylinder {<-2.6,-1.8,-1.2>, <-2.6,-1.8,3.5>, 0.6}}
						object {
							union {
								object {sphere {<-2.6,0,0>, 0.6}}
								object {sphere {<2.6,0,0>, 0.6}}
								object {cylinder {<-2.6,0,0,>, <2.6,0,0>, 0.6}}
							}
							scale <1,1,0.5>
							translate <0,-1.8,-1.2>
						}
							
					}
				}
				object {
					union {
						object {box {<-2.6,-2.3,3.25>, <2.6,-1.3,3.5>}}
						object {cylinder {<2.6,-1.8,3.25>, <2.6,-1.8,3.5>, 0.5}}
						object {cylinder {<-2.6,-1.8,3.25>, <-2.6,-1.8,3.5>, 0.5}}
						object {box {<-1.71,-1.31,3.25>, <1.71,-1.19,3.75>}}
					}
					translate <0,0,0.001>
				}
				#declare SH_Outlet = object {
					union {
						object {cylinder {<-0.8,0,-0.2>, <-0.8,0,0.2>, 0.3}}
						object {cylinder {<0.8,0,-0.2>, <0.8,0,0.2>, 0.3}}
						object {box {<-0.8,-0.3,-0.2>, <0.8, 0.3, 0.2>}}
					}
				}
				object {SH_Outlet translate <-1.3,-1.8,-1.4>}
				object {SH_Outlet translate <1.3,-1.8,-1.4>}
				// Holes cut out for side wing mounting hinges
				object {cylinder {<-2.6,-1.8,-0.4>, <-2.6,-1.8,-0.2>, 0.65}}
				object {cylinder {<-2.6,-1.8,0.2>, <-2.6,-1.8,0.4>, 0.65}}
				object {cylinder {<-2.6,-1.8,2.2>, <-2.6,-1.8,2.4>, 0.65}}
				object {cylinder {<2.6,-1.8,-0.4>, <2.6,-1.8,-0.2>, 0.65}}
				object {cylinder {<2.6,-1.8,0.2>, <2.6,-1.8,0.4>, 0.65}}
				object {cylinder {<2.6,-1.8,2.2>, <2.6,-1.8,2.4>, 0.65}}
			}
		}
		object { // Detail on front of lower body section, just behind cockpit
			union {
				object {box {<-2,-2.4,3.25>, <2, -1.6, 3.35>} texture {SH_HullTex2}}
				object {box {<-1.8,-2.4,3.25>, <1.8, -1.6, 3.4>}}
				object {box {<-0.6,-2.2,3.25>, <0.6, -1.8, 3.45>}}
			}
			texture {
				SH_HullTex1
			}
		}
		object {SH_FormationLight translate <-1,-2.41,2.5>}
		object {SH_FormationLight translate <1,-2.41,2.5>}
		object { // White glow inside engines
			union {
				object {SH_Outlet translate <-1.3,-1.8,-1.2>}
				object {SH_Outlet translate <1.3,-1.8,-1.2>}
			}
			texture {
				pigment {colour rgb 1}
				finish {ambient 1}
			}
		}
		object {SH_Gun1 translate <-2.6,-1.8,3.25>}
		object {SH_Gun1 translate <2.6,-1.8,3.25>}
		object {SH_Gun1 scale <1,1,-1> translate <0,-0.2,-1.25>}
	}
	texture {
		SH_HullTex1
		normal {
			bump_map {gif "sh_bmap4.gif" once}
			rotate <90,0,0>
			translate <-0.5,0,-0.5>
			scale <9,9,-9>
		}
	}
}

#declare SH_CockpitPartA = object {
	difference {
		object {
			union {
				object {cone {<0,0,0>, 1.7, <0,0,4>, 1.3} scale <1,0.2,1>}
				object { // Rear end of cockpit module
					difference {
						object {cone {<0,0,0>, 1.7, <0,0,-0.75>, 1.2} scale <1,0.2,1>}
						object {cone {<0,0,0>, 1.7, <0,0,-0.75>, 1.2} scale <1,0.2,1> scale <0.95,0.95,1.05>}
						object {box {<-0.9,0,-1>, <0.9,1,-0.2>}}
						object {plane {<0,1,0>, 0} translate <0,-0.01,0>}
					}
				}
				object {
					intersection {
						object {cone {<0,0,0>, 1.7, <0,0,-0.75>, 1.2} scale <1,100,1>}
						object {cone {<0,0,0>, 1.7, <0,0,-0.75>, 1.2} scale <1,100,1> scale <0.95,0.95,1.05> inverse}
						object {cone {<0,0,0>, 0.75, <0,-0.8,0>, 0.05} scale <100,1,1>}
					}
				}
				object {
					intersection {
						object {cone {<0,0,0>, 1.7, <0,0,4>, 1.3} scale <1,100,1>}
						object {plane {<0,1,0>, 0}}
						object {plane {<0,-1,0>, 0} rotate <-10,0,0> translate <0,-0.8,0>}
					}
				}
			}
		}
		object {box {<-2,-0.3,0.5>, <2, 2, 2>} rotate <-10,0,0> translate <0,-0.2,0>}
		object {box {<-1.27,-2,1>, <1.27,-0.02,5>}}
		object {
			intersection {
				object {
					union {
						object {box {<-1.5,0,3>, <-1.03,0.07,5>}}
						object {box {<-1.5,0.09,3>, <-1.03,0.16,5>}}
						object {box {<-1.5,0.18,3>, <-1.03,0.25,5>}}

						object {box {<-1,0,3>, <-0.365,0.07,5>}}
						object {box {<-1,0.09,3>, <-0.365,0.16,5>}}
						object {box {<-1,0.18,3>, <-0.365,0.25,5>}}

						object {box {<-0.335,0,3>, <0.335,0.07,5>}}
						object {box {<-0.335,0.09,3>, <0.335,0.16,5>}}
						object {box {<-0.335,0.18,3>, <0.335,0.25,5>}}

						object {box {<0.365,0,3>, <1,0.07,5>}}
						object {box {<0.365,0.09,3>, <1,0.16,5>}}
						object {box {<0.365,0.18,3>, <1,0.25,5>}}

						object {box {<1.03,0,3>, <1.5,0.07,5>}}
						object {box {<1.03,0.09,3>, <1.5,0.16,5>}}
						object {box {<1.03,0.18,3>, <1.5,0.25,5>}}
						
						object {box {<-2,-2,-1>, <2,2,0.5>}}
					}
				}
				object {cone {<0,0,0>, 1.6, <0,0,4>, 1.2} scale <1.05,0.19,1.001>}
			}
		}
	}
	texture {
		SH_HullTex1
		normal {
			bump_map {
				gif "sh_bmap3.gif" once
			}
			rotate <90,0,0>
			scale 6
			translate <-3,0,-1>
		}
	}
}
#declare SH_Screen = object {
	intersection {
		object {
			union {
				object {cone {<0,0,0>, 1.65, <0,0,4>, 1.25} scale <1,0.2,1>}
				object {
					intersection {
						object {cone {<0,0,0>, 1.65, <0,0,4>, 1.25}  scale <1,100,1>}
						object {plane {<0,1,0>, 0}}
						object {plane {<0,-1,0>, 0} translate <0,-1,0>}
					}
				}
			}
		}
		object {plane {<0,-1,0>, 0} rotate <-10,0,0> translate <0,-0.5,0>}
		object {
			box {<-2,-0.5,0.25>, <2, 2, 2.5>}
		}
	}
	texture {
		pigment {colour rgb 0.01}
		finish {specular 0.9 roughness 0.001 reflection 0.1}
	}
		
}		

#declare SH_Cockpit = object {
	union {
		object {SH_CockpitPartA}
		object {SH_Screen}
		#declare SH_Foo4 = object {  // Side underside 'nerf bars' on cockpit module
			intersection {
				object {box {<0,-1,0>, <0.03, 0, 4.1>}}
				object {
					union {
						object {cone {<0,0,0>, 0, <0,0,1>, 0.5} scale <100,1,1>}
						object {cone {<0,0,1>, 0.5, <0,0,4.1>, 0.2} scale <100,1,1>}
					}
				}
			}
			texture {SH_HullTex1}
			rotate <0,0,35>
			rotate <0,4.25,0>
			translate <-1.6,0,0>
			rotate <-10,0,0>
			translate <0,-0.8,0>
		}
		object {SH_Foo4 scale <1,1,1>}
		object {SH_Foo4 scale <-1,1,1>}
		#declare SH_UnderCockpitFin = object {
			intersection {
				object {box {<-0.015,-0.5,0>, <0.015,0,4>}}
				object {
					union {
						object {cylinder {<0,0,0>, <0,-0.1,0>, 4}}
						object {cone {<0,-0.1,0>, 4, <0,-0.4,0>, 3.75}}
					}
					scale <10,1,1>
				}
			}
			translate <0,0,-4>
			rotate <-10,0,0>
			translate <0,0,4>
			texture {SH_HullTex1}
		}
		object {SH_UnderCockpitFin translate <-0.6,0,0>}
		object {SH_UnderCockpitFin translate <-0.3,0,0>}
		object {SH_UnderCockpitFin translate <0,0,0>}
		object {SH_UnderCockpitFin translate <0.3,0,0>}
		object {SH_UnderCockpitFin translate <0.6,0,0>}
	}
	scale 0.9
}

#declare SH_CockpitMount = object {
	union {
		object { // Main central bit of cockpit mount
			intersection {
				object {box {<-1.3,-2,0>, <1.3,2,5>}}
				object {
					union {
						object {cone {<0,0,0>, 1.3, <0,1,0>, 1.1} scale <1,1,100>}
						object {cone {<0,-0.25,0>, 0.8, <0,0,0>, 1.3} scale <1,1,100>}
						object {cone {<0,-0.5,0>, 0.5, <0,-0.25,0>, 0.7} scale <1,1,100>}
						
					}
				}
				object {
					plane {<0,1,0>, 0} rotate <30,0,0> translate <0,0,2.5>}
			}
		}
	}
	scale <0.9,1,1>
	texture {SH_HullTex2}
	translate <0,-1.4,3.6>
}

#declare SH_HingePartA = object {
	union {
		object {box {<0,0,-0.09>, <1.1,0.2,0.09>}}
		#declare Count = 0
		#while (Count < 1)
		object {box {<0,0.2,-0.09>, <0.07,0.25,0.09>} translate <Count,0,0>}
		#declare Count = Count + 0.1
		#end
	}
}

#declare SH_Hinge = object {
	union {
		object {cylinder {<0,0,-0.0901>, <0,0,0.0901>, 0.55} texture {SH_HullTex2}}
		object {SH_HingePartA rotate <0,0,-10> translate <0,0.15,0>}
		object {SH_HingePartA rotate <0,0,-10> translate <0,0.15,0> scale <1,-1,1>}
		object {
			intersection {
				object {cylinder {<0,0,-0.09>, <0,0,0.09>, 0.595}}
				object {
					union {
						#declare Count = 0
						#while (Count < 360)
						object {box {<-0.035, -1, -0.1>, <0.035, 1, 0.1>} rotate <0,0,Count>}
						#declare Count = Count + 12
						#end
					}
				}
			}
		}
	}
	texture {
		SH_HullTex1
	}
	rotate <0,0,-45>
}
#declare SH_Gun2PartA = object {
	union {
		object {
			torus {0.3,0.05}
			rotate <0,0,90>
			translate <0.35,0,0>
		}
		object {
			intersection {
				object {sphere {<0,0,0>, 1} scale <0.4,1,1>}
				object {plane {<-1,0,0>, 0}}
			}
		}
		object {
			intersection {
				object {box {<0,0,-1>, <0.2,1.01,1>}}
				object {cone {<0,0,0>, 0.8, <0,1,0>, 0.4} scale <100,1,1>}
			}
		}
		object {
			difference {
				union {
					object {cylinder {<0.1,0.8,0>, <0.1,0.8,1.5>, 0.085}}
					object {cylinder {<0.1,0.8,0>, <0.1,0.8,2.4>, 0.06}}
					object {cylinder {<0.1,0.8,2.3>, <0.1,0.8,2.7>, 0.075}}
				}
				object {cylinder {<0.1,0.8,0>, <0.1,0.8,3>, 0.055}}
			}
		}
	}
	texture {SH_HullTex1}
}

#declare SH_Gun2 = object {
	union {
		object {SH_Gun2PartA translate <0.4,0,0> scale <1,1,1>}
		object {SH_Gun2PartA translate <0.4,0,0> scale <-1,1,1>}
		object {cylinder {<-0.4,0.8,1.2>, <0.4,0.8,1.2>, 0.08} texture {SH_GunTex1}}
	}
	scale 0.4
}
#declare SH_Wing = object {
	union {
		object {SH_Hinge translate <0,0,-0.3>}
		object {SH_Hinge translate <0,0,0.3>}
		object {SH_Hinge translate <0,0,2.3>}
		object {
			union {
				object {box {<0.65, -0.1,-0.8>, <2, 0.1, 3.2>}}
				object {
					SH_Gun2
					//rotate <80,0,0> // Rotation around mounting pivot - uncomment rotate command for landed position
					rotate <0,0,90>
					translate <1.3,0,2.8>
				}
				
				object {
					SH_FormationLight
					translate <0,7.9,2.01>
					rotate <0,0,-45>
					translate <2, 0, -0.8>
				}
				object {
					intersection {
						object {box {<-0.2,0,0>, <0,8,4>}}
						object {cone {<0,0,0>, 4, <0,8,0>, 2} scale <100,1,1>}
					}
					rotate <0,0,-45>
					translate <2, -0.1, -0.8>
				}
				rotate <0,0,-45>
			}
			texture {
				SH_HullTex1
				normal {
					bump_map {
						gif "sh_bmap2.gif" once
					}
					rotate <90,0,0>
					scale 12
					translate <-2,0,-6>
				}
			}
		}
	}
	texture {SH_HullTex1}
}
#declare SH_L_Wing = object {
	union {
		object {SH_Hinge translate <0,0,-0.3>}
		object {SH_Hinge translate <0,0,0.3>}
		object {SH_Hinge translate <0,0,2.3>}
		object {
			union {
				object {box {<0.65, -0.1,-0.8>, <2, 0.1, 3.2>}}
				object {
					SH_Gun2
					rotate <80,0,0> // Rotation around mounting pivot to landing position
					rotate <0,0,90>
					translate <1.3,0,2.8>
				}
				object {
					SH_FormationLight
					translate <0,7.9,2.01>
					rotate <0,0,-45>
					translate <2, 0, -0.8>
				}
				object {
					intersection {
						object {box {<-0.2,0,0>, <0,8,4>}}
						object {cone {<0,0,0>, 4, <0,8,0>, 2} scale <100,1,1>}
					}
					rotate <0,0,-45>
					translate <2, -0.1, -0.8>
				}
				rotate <0,0,-45>
			}
			texture {
				SH_HullTex1
				normal {
					bump_map {
						gif "sh_bmap2.gif" once
					}
					rotate <90,0,0>
					scale 12
					translate <-2,0,-6>
				}
			}
		}
	}
	texture {SH_HullTex1}
}
#declare SH_Halo = halo {
	emitting
	linear
	colour_map {
		[0 colour rgbt 1]
		[1 colour rgbf <0,0.5,0.7,0>]
	}
	samples 10
	turbulence 0.2
}

#declare EngineGlow = object {
	union {
		object {
			cylinder {<0,-1,0>, <0,1,0>, 1}
			hollow
			no_shadow
			texture {
				pigment {colour rgbt 1}
				halo {
					SH_Halo
					cylindrical_mapping
				}
			}
			rotate <0,0,90>
			scale <2,1,1>
		}
		object {
			intersection {
				object {sphere {<0,0,0>, 1}}
				object {plane {<-1,0,0>, 0}}
			}
			hollow
			no_shadow
			texture {
				pigment {colour rgbt 1}
				halo {
					SH_Halo
					spherical_mapping
				}
			}
			translate <1.99,0,0>
		}
		object {
			intersection {
				object {sphere {<0,0,0>, 1}}
				object {plane {<1,0,0>, 0}}
			}
			hollow
			no_shadow
			texture {
				pigment {colour rgbt 1}
				halo {
					SH_Halo
					spherical_mapping
				}
			}
			translate <-1.99,0,0>
		}
	}
	scale <1,0.5,0.7>
}


#declare Shuttle = object {
	union {
		object {SH_Body}
		object {SH_TopWing translate <0,0.75,0>}
		object {SH_Wing rotate <0,0,-35> translate <2.6,-1.8,0>}
		object {SH_Wing rotate <0,0,-35> translate <2.6,-1.8,0> scale <-1,1,1>}
		object {SH_CockpitMount}
		object {SH_Cockpit rotate <30,0,0> translate <0,-0.5,4.5>}
		object {EngineGlow translate <0,-1.8,-1.5>}
	}
	scale 1.2
}

#declare L_Shuttle = object {
	union {
		object {SH_Body}
		object {SH_TopWing translate <0,0.75,0>}
		object {SH_L_Wing rotate <0,0,95> translate <2.6,-1.8,0>}
		object {SH_L_Wing rotate <0,0,95> translate <2.6,-1.8,0> scale <-1,1,1>}
		object {SH_CockpitMount}
		object {SH_Cockpit rotate <30,0,0> translate <0,-0.5,4.5>}
		object {EngineGlow translate <0,-1.8,-1.5>}
	}
	scale 1.2
}